Landing: 034513d779c8
Project / Subsystem
gcc / match
Date
2026-08-22
Author
Andrea Pinski
Commit
034513d779c8662d9464dc0487c7c304c064d74f
Source
github
Perf win
Yes
Breaking
No
All attributes
- project
- gcc
- subsystem
- match
- patch_id
- —
- commit_hash
- 034513d779c8662d9464dc0487c7c304c064d74f
- source_type
- github
- headline
- match: Removes redundant INTEGER_CST checks in widening multiply patterns.
- tldr
- match: Simplifies widening multiply patterns by removing redundant checks, reducing generated code size.
- author
- Andrea Pinski
- outcome
- committed
- performance_win
- true
- breaking_change
- false
- series_id
- —
- series_parts
- []
- tags
-
- • optimization
- • compiler
- discussion_id_link
- —
- bugzilla_pr
- —
- date
- 2026-08-22T00:00:00.000Z
This commit removes redundant checks for INTEGER_CST in several widening multiply patterns within match.pd. These checks were found to be already handled by inner-most matches, making them unnecessary. The removal simplifies the generated code, resulting in a 0.2% reduction in code size (approximately 584 lines).